Module: PluginManager
- Defined in:
- lib/psdk/helpers/plugin_manager.rb,
lib/psdk/helpers/plugin_manager/list.rb,
lib/psdk/helpers/plugin_manager/config.rb,
lib/psdk/helpers/plugin_manager/builder.rb
Overview
Module handling the plugin commands
Defined Under Namespace
Modules: List Classes: Builder, Config
Class Method Summary collapse
-
.build(plugin_name, in_project: true, out_dir: '.') ⇒ Object
Build a plugin.
-
.list ⇒ Object
List all the plugins installed in the current PSDK project.
Class Method Details
.build(plugin_name, in_project: true, out_dir: '.') ⇒ Object
Build a plugin
19 20 21 |
# File 'lib/psdk/helpers/plugin_manager.rb', line 19 def build(plugin_name, in_project: true, out_dir: '.') Builder.new(plugin_name, in_project: in_project, out_dir: out_dir).build end |
.list ⇒ Object
List all the plugins installed in the current PSDK project
11 12 13 |
# File 'lib/psdk/helpers/plugin_manager.rb', line 11 def list List.list_plugins end |