Class: PluginManager::Config

Inherits:
Object
  • Object
show all
Defined in:
lib/psdk/helpers/plugin_manager/config.rb

Overview

Plugin configuration

Instance Attribute Summary collapse

Instance Attribute Details

#added_filesArray<String>

Get all the files added by the plugin (in order to compile the plugin / remove files)

Returns:

  • (Array<String>)


29
30
31
# File 'lib/psdk/helpers/plugin_manager/config.rb', line 29

def added_files
  @added_files
end

#additional_compatibility_scriptString?

Get the script that tests if the plugin is compatible with other plugins

Returns:

  • (String, nil)


26
27
28
# File 'lib/psdk/helpers/plugin_manager/config.rb', line 26

def additional_compatibility_script
  @additional_compatibility_script
end

#authorsArray<String>

Get the plugin authors

Returns:

  • (Array<String>)


11
12
13
# File 'lib/psdk/helpers/plugin_manager/config.rb', line 11

def authors
  @authors
end

#depsArray<Hash>

Get the dependecies or incompatibilities of the plugin

Returns:

  • (Array<Hash>)


17
18
19
# File 'lib/psdk/helpers/plugin_manager/config.rb', line 17

def deps
  @deps
end

#nameString

Get the plugin name

Returns:

  • (String)


8
9
10
# File 'lib/psdk/helpers/plugin_manager/config.rb', line 8

def name
  @name
end

#psdk_compatibility_scriptString?

Get the script that tests if PSDK is compatible with this plugin

Returns:

  • (String, nil)


20
21
22
# File 'lib/psdk/helpers/plugin_manager/config.rb', line 20

def psdk_compatibility_script
  @psdk_compatibility_script
end

#psdk_versionInteger

Get the PSDK version the plugin was installed

Returns:

  • (Integer)


35
36
37
# File 'lib/psdk/helpers/plugin_manager/config.rb', line 35

def psdk_version
  @psdk_version
end

#retry_psdk_compatibility_after_plugin_loadBoolean?

Tell if the psdk_compatibility_script should be executed after all plugins has been loaded

Returns:

  • (Boolean, nil)


23
24
25
# File 'lib/psdk/helpers/plugin_manager/config.rb', line 23

def retry_psdk_compatibility_after_plugin_load
  @retry_psdk_compatibility_after_plugin_load
end

#sha512String

Get the SHA512 of the plugin (computed after it got compiled)

Returns:

  • (String)


32
33
34
# File 'lib/psdk/helpers/plugin_manager/config.rb', line 32

def sha512
  @sha512
end

#versionString

Get the version of the plugin

Returns:

  • (String)


14
15
16
# File 'lib/psdk/helpers/plugin_manager/config.rb', line 14

def version
  @version
end