Class: PluginManager::Config
- Inherits:
-
Object
- Object
- PluginManager::Config
- Defined in:
- lib/psdk/helpers/plugin_manager/config.rb
Overview
Plugin configuration
Instance Attribute Summary collapse
-
#added_files ⇒ Array<String>
Get all the files added by the plugin (in order to compile the plugin / remove files).
-
#additional_compatibility_script ⇒ String?
Get the script that tests if the plugin is compatible with other plugins.
-
#authors ⇒ Array<String>
Get the plugin authors.
-
#deps ⇒ Array<Hash>
Get the dependecies or incompatibilities of the plugin.
-
#name ⇒ String
Get the plugin name.
-
#psdk_compatibility_script ⇒ String?
Get the script that tests if PSDK is compatible with this plugin.
-
#psdk_version ⇒ Integer
Get the PSDK version the plugin was installed.
-
#retry_psdk_compatibility_after_plugin_load ⇒ Boolean?
Tell if the psdk_compatibility_script should be executed after all plugins has been loaded.
-
#sha512 ⇒ String
Get the SHA512 of the plugin (computed after it got compiled).
-
#version ⇒ String
Get the version of the plugin.
Instance Attribute Details
#added_files ⇒ Array<String>
Get all the files added by the plugin (in order to compile the plugin / remove files)
29 30 31 |
# File 'lib/psdk/helpers/plugin_manager/config.rb', line 29 def added_files @added_files end |
#additional_compatibility_script ⇒ String?
Get the script that tests if the plugin is compatible with other plugins
26 27 28 |
# File 'lib/psdk/helpers/plugin_manager/config.rb', line 26 def additional_compatibility_script @additional_compatibility_script end |
#authors ⇒ Array<String>
Get the plugin authors
11 12 13 |
# File 'lib/psdk/helpers/plugin_manager/config.rb', line 11 def @authors end |
#deps ⇒ Array<Hash>
Get the dependecies or incompatibilities of the plugin
17 18 19 |
# File 'lib/psdk/helpers/plugin_manager/config.rb', line 17 def deps @deps end |
#name ⇒ String
Get the plugin name
8 9 10 |
# File 'lib/psdk/helpers/plugin_manager/config.rb', line 8 def name @name end |
#psdk_compatibility_script ⇒ String?
Get the script that tests if PSDK is compatible with this plugin
20 21 22 |
# File 'lib/psdk/helpers/plugin_manager/config.rb', line 20 def psdk_compatibility_script @psdk_compatibility_script end |
#psdk_version ⇒ Integer
Get the PSDK version the plugin was installed
35 36 37 |
# File 'lib/psdk/helpers/plugin_manager/config.rb', line 35 def psdk_version @psdk_version end |
#retry_psdk_compatibility_after_plugin_load ⇒ Boolean?
Tell if the psdk_compatibility_script should be executed after all plugins has been loaded
23 24 25 |
# File 'lib/psdk/helpers/plugin_manager/config.rb', line 23 def retry_psdk_compatibility_after_plugin_load @retry_psdk_compatibility_after_plugin_load end |
#sha512 ⇒ String
Get the SHA512 of the plugin (computed after it got compiled)
32 33 34 |
# File 'lib/psdk/helpers/plugin_manager/config.rb', line 32 def sha512 @sha512 end |
#version ⇒ String
Get the version of the plugin
14 15 16 |
# File 'lib/psdk/helpers/plugin_manager/config.rb', line 14 def version @version end |